/***************************** LICENSE START ***********************************

 Copyright 2012 ECMWF and INPE. This software is distributed under the terms
 of the Apache License version 2.0. In applying this license, ECMWF does not
 waive the privileges and immunities granted to it by virtue of its status as
 an Intergovernmental Organization or submit itself to any jurisdiction.

 ***************************** LICENSE END *************************************/

#ifndef MvObs_DEFINED_
#define MvObs_DEFINED_

#include "MvBufrObs.h"
#include "MvObsSet.h"

#ifdef METVIEW_PREPBUFR
#include "MvPrepBufrPrep.h"
#endif

#endif  // MvObs_DEFINED_
